Index — Formbar 0.20.3 documentation

# Index

C | F | G | I | L | R | S | V

## C

Config (class in formbar.config)

## F

FieldRenderer (class in formbar.renderer) | Form (class in formbar.form)

## G

get_errors() (formbar.form.Form method) get_form() (formbar.config.Config method) | get_warnings() (formbar.form.Form method)

## I

InfoFieldRenderer (class in formbar.renderer)

## L

load() (in module formbar.config)

## R

render() (formbar.form.Form method)

## S

save() (formbar.form.Form method)

## V

validate() (formbar.form.Form method)